@@ -13,7 +13,9 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with mailmanclient.  If not, see <http://www.gnu.org/licenses/>.
-from six.moves.urllib_error import HTTPError
+
+from urllib.error import HTTPError
+from urllib.parse import quote_plus
 
 from mailmanclient.restobjects.mailinglist import MailingList
 from mailmanclient.restbase.base import RESTList, RESTObject
@@ -57,7 +59,7 @@ class Bans(RESTList):
             # Avoid getting the whole list just to check membership
             try:
                 response, content = self._connection.call(
-                    '{}/{}'.format(self._url, item))
+                    '{}/{}'.format(self._url, quote_plus(item)))
             except HTTPError as e:
                 if e.code == 404:
                     return False
@@ -69,7 +71,8 @@ class Bans(RESTList):
     def add(self, email):
         response, content = self._connection.call(self._url, dict(email=email))
         self._reset_cache()
-        return BannedAddress(self._connection, response['location'])
+        return BannedAddress(
+            self._connection, response.headers.get('location'))
 
     def find_by_email(self, email):
         for ban in self:
